# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['deutschland',
 'deutschland.feiertage',
 'deutschland.feiertage.api',
 'deutschland.feiertage.apis',
 'deutschland.feiertage.model',
 'deutschland.feiertage.models']

package_data = \
{'': ['*']}

install_requires = \
['python-dateutil', 'urllib3>=1.25.3']

setup_kwargs = {
    'name': 'de-feiertage',
    'version': '1.0.1',
    'description': 'Feiertage API',
    'long_description': '# feiertage\nDeutsche Feiertage per JSON-Webservice (API) \n\nThis Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:\n\n- API version: 1.0.0\n- Package version: 1.0.1\n- Build package: org.openapitools.codegen.languages.PythonClientCodegen\nFor more information, please visit [https://bund.dev](https://bund.dev)\n\n## Requirements.\n\nPython >= 3.6\n\n## Installation & Usage\n### pip install\n\n```sh\npip install deutschland[feiertage]\n```\n\n### poetry install\n\n```sh\npoetry add deutschland -E feiertage\n```\n\n### Setuptools\n\nInstall via [Setuptools](http://pypi.python.org/pypi/setuptools).\n\n```sh\npython setup.py install --user\n```\n(or `sudo python setup.py install` to install the package for all users)\n\n## Usage\n\nImport the package:\n```python\nfrom deutschland import feiertage\n```\n\n## Getting Started\n\nPlease follow the [installation procedure](#installation--usage) and then run the following:\n\n```python\n\nimport time\nfrom deutschland import feiertage\nfrom pprint import pprint\nfrom deutschland.feiertage.api import default_api\n# Defining the host is optional and defaults to https://feiertage-api.de/api\n# See configuration.py for a list of all supported configuration parameters.\nconfiguration = feiertage.Configuration(\n    host = "https://feiertage-api.de/api"\n)\n\n\n\n# Enter a context with an instance of the API client\nwith feiertage.ApiClient(configuration) as api_client:\n    # Create an instance of the API class\n    api_instance = default_api.DefaultApi(api_client)\n    jahr = "2021" # str | Welches Jahr?\n    nur_land = "BW" # str | Welches Bundesland? (optional)\n    nur_daten = 1 # int | Nur Daten oder auch Hinweise? (optional)\n\n    try:\n        # Get Feiertage\n        api_response = api_instance.get_feiertage(jahr, nur_land=nur_land, nur_daten=nur_daten)\n        pprint(api_response)\n    except feiertage.ApiException as e:\n        print("Exception when calling DefaultApi->get_feiertage: %s\\n" % e)\n```\n\n## Documentation for API Endpoints\n\nAll URIs are relative to *https://feiertage-api.de/api*\n\nClass | Method | HTTP request | Description\n------------ | ------------- | ------------- | -------------\n*DefaultApi* | [**get_feiertage**](docs/DefaultApi.md#get_feiertage) | **GET** / | Get Feiertage\n\n\n## Documentation For Models\n\n - [Feiertag](docs/Feiertag.md)\n\n\n## Documentation For Authorization\n\n All endpoints do not require authorization.\n\n## Author\n\nkontakt@bund.dev\n\n\n## Notes for Large OpenAPI documents\nIf the OpenAPI document is large, imports in feiertage.apis and feiertage.models may fail with a\nRecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:\n\nSolution 1:\nUse specific imports for apis and models like:\n- `from deutschland.feiertage.api.default_api import DefaultApi`\n- `from deutschland.feiertage.model.pet import Pet`\n\nSolution 2:\nBefore importing the package, adjust the maximum recursion limit as shown below:\n```\nimport sys\nsys.setrecursionlimit(1500)\nfrom deutschland import feiertage\nfrom deutschland.feiertage.apis import *\nfrom deutschland.feiertage.models import *\n```\n\n',
    'author': 'BundesAPI',
    'author_email': 'kontakt@bund.dev',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/bundesAPI/feiertage-api',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6',
}


setup(**setup_kwargs)
